==> haskell-network-multicast-0.3.2-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-GY2juN2PzI7IPcAbMUsjB2
key:                  network-multicast-0.3.2-GY2juN2PzI7IPcAbMUsjB2
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  8d346bc6310518f226df86ba3af9b82d
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-8.10.4/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/network-multicast-0.3.2
hs-libraries:         HSnetwork-multicast-0.3.2-GY2juN2PzI7IPcAbMUsjB2
depends:
    base-4.14.1.0 network-3.1.2.1-DRWh3PXxLpgEA96GNEGjqt
    network-bsd-2.8.1.0-DmpQTeQVFvG4tJfRNoqsgj

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.3.2-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-6Jtc98toCrJ7Pkkd8Jf4WI
key:                  network-multicast-0.3.2-6Jtc98toCrJ7Pkkd8Jf4WI
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  40cd66619957fdcac803833ea439627b
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-8.10.4/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/network-multicast-0.3.2
hs-libraries:         HSnetwork-multicast-0.3.2-6Jtc98toCrJ7Pkkd8Jf4WI
depends:
    base-4.14.1.0 network-3.1.2.1-FhOaehNchti9X3Dj4Rfk7n
    network-bsd-2.8.1.0-qizcXaWdBRL3ZRPK8sBOJ

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
